package
Version:
v0.0.0-...-c88a890
Opens a new window with list of versions in this module.
Published: Dec 23, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Account struct {
Address ID `gorm:"unique;not null" json:"id"`
Name string `json:"owner"`
gorm.Model
}
type AccountCreateDTO struct {
Address string `json:"account"`
Name string `json:"name"`
}
type FaucetsStore interface {
AddToList(address string)
IsFullfilledLast24H(address string) bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.